#[repr(u8)]pub enum CmdcrcEn {
EXIT = 0,
CLR = 1,
}Variants
EXIT = 0
Disables the CRC command CRC. The CRC command will not be updated on completion of each ELS command.
CLR = 1
Enables the CRC command. The CRC command will be updated on completion of each ELS command.
Implementations